@@ -26,7 +26,7 @@ import socket
 
 
 # The current version of duplicity
-version = "0.6.26"
+version = "0.7.13.1"
 
 # Prefix for all files (appended before type-specific prefixes)
 file_prefix = ""
@@ -79,6 +79,8 @@ backend = None
 # source directory.
 select = None
 
+gpg_binary = None
+
 # Set to GPGProfile that will be used to compress/uncompress encrypted
 # files.  Replaces encryption_keys, sign_key, and passphrase settings.
 gpg_profile = None
@@ -87,7 +89,7 @@ gpg_profile = None
 gpg_options = ''
 
 # Maximum file blocksize
-max_blocksize = 2048L
+max_blocksize = 2048
 
 # If true, filelists and directory statistics will be split on
 # nulls instead of newlines.
@@ -105,6 +107,7 @@ pydevd = False
 time_separator = ":"
 
 # Global lockfile used to manage concurrency
+lockpath = ""
 lockfile = None
 
 # If this is true, only warn and don't raise fatal error when backup
@@ -151,8 +154,8 @@ encryption = True
 # If set to false, then do not compress files on remote system
 compression = True
 
-# volume size. default 25M
-volsize = 25 * 1024 * 1024
+# volume size. default 200M
+volsize = 200 * 1024 * 1024
 
 # Working directory for the tempfile module. Defaults to /tmp on most systems.
 temproot = None
@@ -189,6 +192,9 @@ s3_unencrypted_connection = False
 # Whether to use S3 Reduced Redudancy Storage
 s3_use_rrs = False
 
+# Whether to use S3 Infrequent Access Storage
+s3_use_ia = False
+
 # True if we should use boto multiprocessing version
 s3_use_multiprocessing = False
 
@@ -231,20 +237,15 @@ sftp_command = None
 # default to batch mode using public-key encryption
 ssh_askpass = False
 
-# default ssh backend is pexpect
-ssh_backend = "pexpect"
-
 # user added ssh options
 ssh_options = ""
 
-# whether to use scp for put/get, sftp is default
-use_scp = False
-
 # default cf backend is pyrax
 cf_backend = "pyrax"
 
-# HTTPS ssl optons (currently only webdav)
+# HTTPS ssl options (currently only webdav, lftp)
 ssl_cacert_file = None
+ssl_cacert_path = None
 ssl_no_check_certificate = False
 
 # user added rsync options
@@ -274,6 +275,10 @@ rename = {}
 # enable data comparison on verify runs
 compare_data = False
 
+# When symlinks are encountered, the item they point to is copied rather than
+# the symlink.
+copy_links = False
+
 # When selected, triggers a dry-run before a full or incremental to compute
 # changes, then runs the real operation and keeps track of the real progress
 progress = False
@@ -287,3 +292,12 @@ par2_redundancy = 10
 
 # Verbatim par2 other options
 par2_options = ""
+
+# Whether to enable gio backend
+use_gio = False
+
+# If set, collect only the file status, not the whole root.
+file_changed = None
+
+# delay (in seconds) before next operation after failure
+backend_retry_delay = 30
